import os

from blue_objects import file, README

from blue_sandbox import NAME, VERSION, ICON, REPO_NAME


items = [
    "{}[`{}`]({}) [![image]({})]({}) {}".format(
        "🌐",
        "`@damage`",
        "https://github.com/kamangir/blue-sandbox/blob/main/blue_sandbox/microsoft_building_damage_assessment/README.md",
        "https://github.com/microsoft/building-damage-assessment/raw/main/figures/damage.png",
        "https://github.com/kamangir/blue-sandbox/blob/main/blue_sandbox/microsoft_building_damage_assessment/README.md",
        "Satellite imagery damage assessment workflow",
    )
] + [
    "{}[`{}`](#) [![image]({})](#) {}".format(
        ICON,
        f"experiment {index}",
        "https://github.com/kamangir/assets/raw/main/blue-plugin/marquee.png?raw=true",
        f"description of experiment {index} ...",
    )
    for index in range(2, 4)
]


def build():
    return README.build(
        items=items,
        path=os.path.join(file.path(__file__), ".."),
        ICON=ICON,
        NAME=NAME,
        VERSION=VERSION,
        REPO_NAME=REPO_NAME,
    ) and README.build(
        path=os.path.join(file.path(__file__), "microsoft_building_damage_assessment"),
        ICON=ICON,
        NAME=NAME,
        VERSION=VERSION,
        REPO_NAME=REPO_NAME,
    )



from typing import List

from blue_options.terminal import show_usage, xtra


def help_ingest(
    tokens: List[str],
    mono: bool,
) -> str:
    options = xtra("~download,~upload", mono=mono)

    args = [
        "[--verbose 1]",
    ]

    return show_usage(
        [
            "@damage",
            "ingest",
            f"[{options}]",
            "[-|<object-name>]",
        ]
        + args,
        "ingest @damage data.",
        mono=mono,
    )


help_functions = {
    "ingest": help_ingest,
}



from abcli.help.generic import help_functions as generic_help_functions

from blue_sandbox import ALIAS

from blue_sandbox.help.microsoft_building_damage_assessment import (
    help_functions as help_microsoft_building_damage_assessment,
)


help_functions = generic_help_functions(plugin_name=ALIAS)

help_functions.update(
    {
        "microsoft_building_damage_assessment": help_microsoft_building_damage_assessment,
    }
)
